#
# spec file for package pnpm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# to avoid empty debugfiles error on some distros
%global debug_package %{nil}
# The internal dependency generator adds lots of unnecessary Requires:
# and strange Provides: own(foo) because it slurps in all package.json
%global __nodejs_provides %{nil}
%global __nodejs_requires %{nil}
Name:           pnpm
Version:        9.11.0
Release:        1.1
Summary:        Fast, disk space efficient package manager
License:        MIT
Group:          Development/Languages/Other
URL:            https://pnpm.io/
Source:         https://registry.npmjs.org/%{name}/-/%{name}-%{version}.tgz
BuildRequires:  fdupes
BuildRequires:  nodejs-devel >= 18
BuildRequires:  nodejs-packaging
Requires:       bash
Recommends:     python3
Provides:       npm(%{name}) = %{version}
BuildArch:      noarch

%description
pnpm is a package manager for node.js

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       zsh
Supplements:    (%{name} and zsh)

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       fish
Supplements:    (%{name} and fish)

%description fish-completion
Fish command line completion support for %{name}.

%prep
%setup -q -n package

%build
# nothing to do

%install
%nodejs_install

# PATCH FILES

fix_executable() { chmod 775 "$1"; sed -i '1 s|^\(#!.*/\)env |\1|' "$1"; }
export -f fix_executable

# Patch hashbang in pnpm
sed -i -e 's|#!%{_bindir}/env node|#!%{_bindir}/node|' %{buildroot}%{nodejs_sitelib}/pnpm/bin/*

sed -i '1 s|^\(#!.*/\)env |\1|' %{buildroot}%{nodejs_sitelib}/pnpm/dist/node-gyp-bin/node-gyp

# Non-executable scripts
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules -type f -path '*/bin/*' \
    -exec sh -c 'fix_executable {}' \;
fix_executable %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/glob/dist/esm/bin.mjs

# Remove unnecessary shebangs
sed -i '1!b;\|#!/|d' %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/glob/dist/esm/bin.d.mts
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/node-gyp/gyp -type f \
    -exec sed -i '1!b;\|#!/|d' {} \;

# SHELL COMPLETION

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions
%{buildroot}%{_bindir}/pnpm completion bash > %{buildroot}%{_datadir}/bash-completion/completions/%{name}
mkdir -p %{buildroot}%{_datadir}/zsh/site-functions
%{buildroot}%{_bindir}/pnpm completion zsh > %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
mkdir -p %{buildroot}%{_datadir}/fish/vendor_completions.d
%{buildroot}%{_bindir}/pnpm completion fish > %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

# CLEANUP

# Hidden files
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules -type f -name '.*' -delete

# Hidden directories
find %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules -type d -name '.*' -print0 | xargs -0 -n1 rm -rvf

# Non-Linux files
rm -rf %{buildroot}%{nodejs_sitelib}/pnpm/dist/vendor
rm -f %{buildroot}%{nodejs_sitelib}/pnpm/dist/reflink.{darwin,win32}*.node
rm -f %{buildroot}%{nodejs_sitelib}/pnpm/dist/node_modules/node-gyp/macOS_*
find %{buildroot}%{nodejs_sitelib}/pnpm/dist -type f \
    \( -name '*.cmd' -o -name '*.bat' -o -name '*.ps1' \) -delete

%fdupes %{buildroot}

%check

%files
%license LICENSE
%doc README.md
%{_bindir}/pnp{m,x}
%{nodejs_sitelib}

%files bash-completion
%{_datadir}/bash-completion/

%files zsh-completion
%{_datadir}/zsh/

%files fish-completion
%{_datadir}/fish/

%changelog
* Sat Sep 21 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.11.0:
  * Experimental: added pnpm cache commands for inspecting the
    metadata cache #8512
  * Fix a regression in which pnpm deploy with node-linker=hoisted
    produces an empty node_modules directory #6682
  * pnpm deploy should work in workspace with shared-workspace-lockfile=false #8475
  * Don't print a warning when linking packages globally #4761
* Wed Sep 11 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.10.0:
  * Support for a new CLI flag, --exclude-peers, added to the
    list and why commands. When --exclude-peers is used, peer
    dependencies are not printed in the results, but dependencies
    of peer dependencies are still scanned #8506.
  * Added a new setting to package.json at pnpm.auditConfig.
    ignoreGhsas for ignoring vulnerabilities by their GHSA code #6838.
  * Throw an exception if pnpm switches to the same version of itself.
  * Reduce memory usage during peer dependencies resolution.
* Mon Sep  2 2024 Virinas-code <Virinas-code@opensuse.org>
- update to version 9.9.0:
  * https://github.com/pnpm/pnpm/compare/v9.8.0...v9.9.0
  * Minor breaking change. We had to optimize how we resolve peer
    dependencies in order to fix some infinite loops and
    out-of-memory errors during peer dependencies resolution.
  * pnpm deploy should write the node_modules/.modules.yaml to the
    node_modules directory within the deploy directory #7731
  * Don't override a symlink in node_modules if it already points
    to the right location pnpm/symlink-dir#54
- changes from 9.8.0:
  * https://github.com/pnpm/pnpm/compare/v9.7.1...v9.8.0
  * Added a new command for upgrading pnpm itself when it isn't
    managed by Corepack: pnpm self-update. This command will work,
    when pnpm was installed via the standalone script from the pnpm
    installation page #8424
  * CLI tools installed in the root of the workspace should be
    added to the PATH, when running scripts and use-node-version is
    set
  * pnpm setup should never switch to another version of pnpm
  * Ignore non-string value in the os, cpu, libc fields, which
    checking optional dependencies #8431
  * Remember the state of edit dir, allow running pnpm patch-commit
    the second time without having to re-run pnpm patch
- changes from 9.7.1:
  * https://github.com/pnpm/pnpm/compare/v9.7.0...v9.7.1
  * Fixed passing public-hoist-pattern and hoist-pattern via env
    variables #8339
  * pnpm setup no longer creates Batch/Powershell scripts on Linux
    and macOS #8418
  * When dlx uses cache, use the real directory path not the
    symlink to the cache #8421
  * pnpm exec now supports executionEnv #8356
  * Remove warnings for non-root pnpm field, add warnings for
    non-root pnpm subfields that aren't executionEnv #8143
  * Replace semver in "peerDependency" with workspace protocol
    [#8355]
  * Fix a bug in patch-commit in which relative path is rejected
    [#8405]
  * Update Node.js in @pnpm/exe to v20
- changes from 9.7.0:
  * https://github.com/pnpm/pnpm/compare/v9.6.0...v9.7.0
  * Added pnpm version management. If the
    manage-package-manager-versions setting is set to true, pnpm
    will switch to the version specified in the packageManager
    field of package.json #8363
  * Added the ability to apply patch to all versions #8337
  * Change the default edit dir location when running pnpm patch
    from a temporary directory to
    node_modules/.pnpm_patches/pkg[@version] to allow the code
    editor to open the edit dir in the same file tree as the main
    project #8379.
  * Substitute environment variables in config keys #6679
  * pnpm install should run node-gyp rebuild if the project has a
    binding.gyp file even if the project doesn't have an install
    script #8293
  * Print warnings to stderr #8342
  * Peer dependencies of optional peer dependencies should be
    automatically installed #8323
* Thu Jul 25 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.6.0:
  * Support specifying node version (via pnpm.executionEnv.nodeVersion
    in package.json) for running lifecycle scripts per each package
    in a workspace #6720
  * Overrides now support the catalogs: protocol #8303
  * The pnpm deploy command now supports the catalog: protocol #8298
  * The pnpm outdated command now supports the catalog: protocol #8304
  * Correct the error message when trying to run pnpm patch
    without node_modules/.modules.yaml #8257
  * Silent reporting fixed with the pnpm exec command #7608
  * Add registries information to the calculation of dlx cache hash #8299
* Tue Jul  9 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.5.0:
  * Added support for catalogs #8122
  * Read authentication information from .npmrc in the current
    directory when running dlx #7996
  * Updated @pnpm/tabtab to v0.5.4, enabling zsh autocomplete
    lazy loading #8236
  * Installation with filtering will now work, when dedupe-peer-
    dependents is set to true #6300
  * Fixed dlx not actually using the Node.js version specified by
  - -use-node-version.
* Sat Jul  6 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.4.0:
  * Some registries allow the exact same content to be published
    under different package names and/or versions. This breaks
    the validity checks of packages in the store. To avoid errors
    when verifying the names and versions of such packages in the
    store, you may now set the strict-store-pkg-content-check
    setting to false #4724
  * Fix package-manager-strict-version missing in config #8195
  * If install is performed on a subset of workspace projects,
    always create an up-to-date lockfile first. So, a partial
    install can be performed only on a fully resolved (non-partial)
    lockfile #8165
  * Handle workspace protocol with any semver range specifier,
    when used in peer dependencies #7578
* Fri Jun 14 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.3.0:
  * Semi-breaking. Dependency key names in the lockfile are
    shortened if they are longer than 1000 characters. We don't
    expect this change to affect many users. Affected users most
    probably can't run install successfully at the moment. This
    change is required to fix some edge cases in which installation
    fails with an out-of-memory error or "Invalid string length
    (RangeError: Invalid string length)" error. The max allowed
    length of the dependency key can be controlled with the peers-
    suffix-max-length setting #8177.
  * Set reporter-hide-prefix to true by default for pnpm exec. In
    order to show prefix, the user now has to explicitly set reporter
  - hide-prefix=false #8174.
- changes from 9.2.0:
  * If package-manager-strict-version is set to true, pnpm will
    fail if its version doesn't exactly match the version in the
    "packageManager" field of package.json.
  * Update @yarnpkg/pnp to the latest version, fixing issue with
    node: imports #8161.
  * Deduplicate bin names to prevent race condition and corrupted
    bin scripts #7833.
  * pnpm doesn't fail if its version doesn't match the one
    specified in the "packageManager" field of package.json #8087.
  * exec now also streams prefixed output when --recursive or
  - -parallel is specified just as run does #8065.
- changes from 9.1.4:
  * Improved the performance of the resolution stage by changing
    how missing peer dependencies are detected #8144.
- changes from 9.1.3:
  * Fix a bug in which a dependency that is both optional for one
    package but non-optional for another is omitted when optional=false #8066.
  * Clear resolution cache before starting peer dependencies resolution #8109.
  * Reduce memory usage by peer dependencies resolution #8072.
* Tue May 21 2024 draskmont@protonmail.com
- update to version 9.1.2
- require nodejs >= 18
* Sat Apr 27 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to version 9.0.6:
  * Lockfiles that have git-hosted dependencies specified should
    be correctly converted to the new lockfile format #7990.
  * Don't upgrade the lockfile format on pnpm install
  - -frozen-lockfile #7991.
- includes version 9.0.5:
  * Lockfiles with local or git-hosted dependencies are now
    successfully converted to the new lockfile format #7955.
  * Resolve peer dependencies correctly, when they have
    prerelease versions #7977.
  * Fix aliased dependencies resolution on repeat install with
    existing lockfile, when the aliased dependency doesn't
    specify a version or range #7957.
  * The lockfile should be saved in the new format even if it is
    up-to-date.
- run spec-cleaner
* Sat Apr 20 2024 draskmont@protonmail.com
- update to version 9.0.4
- Added shell completion subpackages for bash, zsh and fish
- Removed python2 dependency
- Prevent packaging of executable files for other OS.
- Cleaned up specfile:
  * Removed some unused tags, macros and redudant requirements
  * Added licensing header
  * Fixed rpmlint errors and warnings
- Removed unused _service file
- Restored changelog
* Thu Jan 25 2024 Marcel Kuehlhorn <tux93@opensuse.org>
- update to version 8.14.3
  * https://github.com/pnpm/pnpm/compare/v8.4.0...v8.14.3
* Mon Jan 14 2019 John Vandenberg <jayvdb@gmail.com>
- initial revision for pnpm 2.25.1
